@@ -7,20 +7,20 @@ import sys
 import os
 import json
 from zipfile import ZipFile
-import importlib.util
 import multiprocessing
 from livereload import Server
 import click
-
 import requests
 
+from scintillant import addons_versions
+
 
 def create_snlt():
     with open(os.getcwd() + '/.snlt', 'w+') as snlt:
         if sys.platform == 'win32':
             std_path = 'C:\\snlt\\testsuite\\'
         else:
-            std_path = '/opt/sntl/testsuite/'
+            std_path = '/ust/testsuite/'
         path = input("Specify the path where Python can create "
                      f"the test environment files ({std_path}): ")
         path = std_path if not path else path
@@ -29,10 +29,11 @@ def create_snlt():
             "skill_name": "bottle-skill-template",
             "skill_working_url": "http://localhost:8080",
             "testsuite": {
+                "version": addons_versions['__testsuite__'],
                 "path": path,
                 "theme": "dark"
             }
-        }, snlt)
+        }, snlt, sort_keys=True, indent=4)
 
 
 def update_snlt():
@@ -40,7 +41,7 @@ def update_snlt():
     if sys.platform == 'win32':
         std_path = 'C:\\snlt\\testsuite\\'
     else:
-        std_path = '/opt/sntl/testsuite/'
+        std_path = './testsuite/'
     path = input("Specify the path where Python can create "
                  f"the test environment files ({std_path}): ")
     path = std_path if not path else path
@@ -50,11 +51,13 @@ def update_snlt():
         elif 'testsuite' not in js:
             js['testsuite'] = {'theme': 'dark'}
             js['testsuite']['path'] = path
-        json.dump(js, snlt)
+        json.dump(js, snlt, sort_keys=True, indent=4)
 
 
 def install_suite(path):
-    suite_release = "https://github.com/PaperDevil/snlt_testsuite/releases/download/v0.0.1/dist.zip"
+    suite_release = ("https://github.com/PaperDevil/snlt_testsuite/releases/download/"
+                     f"{addons_versions['__testsuite__']}"
+                     "/dist.zip")
     r = requests.get(suite_release)
     os.makedirs(os.path.dirname(path + 'temp.zip'), exist_ok=True)
     with open(path + 'temp.zip', 'wb') as f:
@@ -71,7 +74,12 @@ def get_current_app(app_path: str = None):
         from manage import run_app
         return run_app
     except ImportError as exc:
-        raise ImportError("The specified path does not contain a valid manage.py file")
+        raise ImportError(
+            "The specified path does not contain a valid manage.py file. "
+            "Make sure you've installed all the dependencies from the "
+            "requirements.txt file and created the run_app function correctly "
+            "inside the manage.py file!"
+        )
 
 
 def start_bot_server():
