@@ -75,7 +75,7 @@ class ContextUpdater:
         if self.vault:
             self.context['__vault__'] = self.vault.dict()
 
-    def execute_now(self, func: Callable) -> None:
+    def execute_now(self, func: Callable or None) -> None:
         self.next_state = func
         self.execute_state()
 
@@ -120,4 +120,4 @@ class ContextUpdater:
         return wrapper
 
     def setup_logs(self, folder, level='DEBUG', rotation='2 GB'):
-        logger.add(folder + f'{self.__class__}.log', level=level, rotation=rotation)
+        logger.add(folder + f'{self.__class__.__name__}.log', level=level, rotation=rotation)
